==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkPolyLine.java <==
// java wrapper for vtkPolyLine object
//

package vtk;
import vtk.*;

public class vtkPolyLine extends vtkCell
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GenerateSlidingNormals_2(vtkPoints id0,vtkCellArray id1,vtkDataArray id2);
  public int GenerateSlidingNormals(vtkPoints id0,vtkCellArray id1,vtkDataArray id2)
    { return GenerateSlidingNormals_2(id0,id1,id2); }

  private native int GetCellType_3();
  public int GetCellType()
    { return GetCellType_3(); }

  private native int GetCellDimension_4();
  public int GetCellDimension()
    { return GetCellDimension_4(); }

  private native int GetNumberOfEdges_5();
  public int GetNumberOfEdges()
    { return GetNumberOfEdges_5(); }

  private native int GetNumberOfFaces_6();
  public int GetNumberOfFaces()
    { return GetNumberOfFaces_6(); }

  private native long GetEdge_7(int id0);
  public vtkCell GetEdge(int id0) {
    long temp = GetEdge_7(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetFace_8(int id0);
  public vtkCell GetFace(int id0) {
    long temp = GetFace_8(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int CellBoundary_9(int id0,double id1[],vtkIdList id2);
  public int CellBoundary(int id0,double id1[],vtkIdList id2)
    { return CellBoundary_9(id0,id1,id2); }

  private native void Contour_10(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10);
  public void Contour(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10)
    { Contour_10(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9,id10); }

  private native void Clip_11(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9);
  public void Clip(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9)
    { Clip_11(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9); }

  private native int Triangulate_12(int id0,vtkIdList id1,vtkPoints id2);
  public int Triangulate(int id0,vtkIdList id1,vtkPoints id2)
    { return Triangulate_12(id0,id1,id2); }

  private native int IsPrimaryCell_13();
  public int IsPrimaryCell()
    { return IsPrimaryCell_13(); }

  private native int GetParametricCenter_14(double id0[]);
  public int GetParametricCenter(double id0[])
    { return GetParametricCenter_14(id0); }

  public vtkPolyLine() { super(); }

  public vtkPolyLine(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkPolyLine.java <==
// java wrapper for vtkPolyLine object
//

package vtk;
import vtk.*;

public class vtkPolyLine extends vtkCell
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GenerateSlidingNormals_2(vtkPoints id0,vtkCellArray id1,vtkDataArray id2);
  public int GenerateSlidingNormals(vtkPoints id0,vtkCellArray id1,vtkDataArray id2)
    { return GenerateSlidingNormals_2(id0,id1,id2); }

  private native int GetCellType_3();
  public int GetCellType()
    { return GetCellType_3(); }

  private native int GetCellDimension_4();
  public int GetCellDimension()
    { return GetCellDimension_4(); }

  private native int GetNumberOfEdges_5();
  public int GetNumberOfEdges()
    { return GetNumberOfEdges_5(); }

  private native int GetNumberOfFaces_6();
  public int GetNumberOfFaces()
    { return GetNumberOfFaces_6(); }

  private native long GetEdge_7(int id0);
  public vtkCell GetEdge(int id0) {
    long temp = GetEdge_7(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetFace_8(int id0);
  public vtkCell GetFace(int id0) {
    long temp = GetFace_8(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int CellBoundary_9(int id0,double id1[],vtkIdList id2);
  public int CellBoundary(int id0,double id1[],vtkIdList id2)
    { return CellBoundary_9(id0,id1,id2); }

  private native void Contour_10(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10);
  public void Contour(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10)
    { Contour_10(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9,id10); }

  private native void Clip_11(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9);
  public void Clip(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9)
    { Clip_11(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9); }

  private native int Triangulate_12(int id0,vtkIdList id1,vtkPoints id2);
  public int Triangulate(int id0,vtkIdList id1,vtkPoints id2)
    { return Triangulate_12(id0,id1,id2); }

  private native int IsPrimaryCell_13();
  public int IsPrimaryCell()
    { return IsPrimaryCell_13(); }

  private native int GetParametricCenter_14(double id0[]);
  public int GetParametricCenter(double id0[])
    { return GetParametricCenter_14(id0); }

  public vtkPolyLine() { super(); }

  public vtkPolyLine(long id) { super(id); }
  public native long   VTKInit();

}
